#!/usr/bin/env ts-node
"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const commander_1 = require("commander");
const init_executor_1 = require("../Executors/init.executor");
const log_action_1 = require("../../config/logs/log.action");
const generate_executor_1 = require("../Executors/generate.executor");
const db_migration_executor_1 = require("../Executors/db.migration.executor");
const db_seeds_executor_1 = require("../Executors/db.seeds.executor");
const commander = new commander_1.Command();
commander.version("0.0.1").description("Sequelize CLI for TypeScript");
commander
    .command("init")
    .alias("i")
    .description("Initialization CLI dependencies into the project")
    .action(init_executor_1.initialization);
commander
    .command("init:config")
    .alias("i:con")
    .description("Initialization CLI config into the project")
    .action(init_executor_1.initExecutor.initConfig);
commander
    .command("init:migrations")
    .alias("i:mig")
    .description("Initialization CLI migrations into the project")
    .action(init_executor_1.initExecutor.initMigrations);
commander
    .command("init:models")
    .alias("i:mod")
    .description("Initialization CLI models into the project")
    .action(init_executor_1.initExecutor.initModels);
commander
    .command("init:seeds")
    .alias("i:see")
    .description("Initialization CLI seeders into the project")
    .action(init_executor_1.initExecutor.initSeeders);
commander
    .command("migration:generate <tableName> <parameters...>")
    .alias("mig:gen")
    .description("Generation a new migration file into the project")
    .action((tableName, parameters) => generate_executor_1.generateExecutor.generateMigration(tableName, parameters));
commander
    .command("model:generate <modelName> <parameters...>")
    .alias("mod:gen")
    .description("Generation a new model file into the project")
    .action((modelName, parameters) => generate_executor_1.generateExecutor.generateModel(modelName, parameters));
commander
    .command("seed:generate <seedName>")
    .alias("see:gen")
    .description("Generation a new seed file into the project")
    .action((seedName) => generate_executor_1.generateExecutor.generateSeed(seedName));
commander
    .command("db:migrate:up")
    .alias("db:mig:u")
    .description("Migrate all pending migration files")
    .action(db_migration_executor_1.dbMigrationExecutor.up);
commander
    .command("db:mig:down")
    .alias("db:mig:d")
    .description("Drop all database")
    .action(db_migration_executor_1.dbMigrationExecutor.down);
commander
    .command("db:migrate:sdown <parameters...>")
    .alias("db:mig:sd")
    .description("Drop specific migration files")
    .action((parameters) => db_migration_executor_1.dbMigrationExecutor.specificDown(parameters));
commander
    .command("db:migrate:pending")
    .alias("db:mig:p")
    .description("Check all migration files that not executed")
    .action(db_migration_executor_1.dbMigrationExecutor.pending);
commander
    .command("db:migrate:executed")
    .alias("db:mig:e")
    .description("Check all migration files that executed")
    .action(db_migration_executor_1.dbMigrationExecutor.executed);
commander
    .command("db:seed:up")
    .alias("db:s:u")
    .description("Migrate all pending seed files")
    .action(db_seeds_executor_1.dbSeedsExecutor.up);
commander
    .command("db:seed:down")
    .alias("db:s:d")
    .description("Drop all seed files")
    .action(db_seeds_executor_1.dbSeedsExecutor.down);
commander
    .command("db:seed:pending")
    .alias("db:s:p")
    .description("Check all seed files that not executed")
    .action(db_seeds_executor_1.dbSeedsExecutor.pending);
commander
    .command("db:migrate:executed")
    .alias("db:s:e")
    .description("Check all seed files that executed")
    .action(db_seeds_executor_1.dbSeedsExecutor.executed);
commander
    .command("logs")
    .alias("l")
    .description("Shows all logs of action CLI")
    .action(log_action_1.showLogs);
commander.parse(process.argv);
//# sourceMappingURL=commands.js.map