"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.generateExecutor = void 0;
const migrations_template_1 = require("./templates/migrations.template");
const log_action_1 = require("../../config/logs/log.action");
const logs_messages_1 = require("../../config/constants/logs.messages");
const naming_handler_1 = require("../Common/naming.handler");
const models_template_1 = require("./templates/models.template");
const columnBuilder_1 = require("../Common/columnBuilder");
const seed_template_1 = require("./templates/seed.template");
class GenerateExecutor {
    async generateMigration(tableName, parameters) {
        try {
            const separatedParameters = parameters.map((arr) => {
                return arr.split(":");
            });
            const columnData = separatedParameters.map((column) => {
                return columnBuilder_1.migrationColumnBuilder(column[0], column[1]) || "";
            });
            migrations_template_1.createMigrationFile(tableName, columnData);
            console.log(`The migration file ${naming_handler_1.endOfStringFromManyToOne(tableName.toLowerCase())} has been created. Status: Pending`);
            await log_action_1.logAction(logs_messages_1.initializationMessages.successMessages.migrationGeneration +
                ` File: ${naming_handler_1.endOfStringFromManyToOne(tableName.toLowerCase())}`);
        }
        catch (err) {
            console.error(err);
            await log_action_1.logAction(logs_messages_1.initializationMessages.errorMessages.migrationGeneration +
                ` File: ${naming_handler_1.endOfStringFromManyToOne(tableName.toLowerCase())}` +
                " Message: " +
                err.message);
        }
    }
    async generateModel(modelName, parameters) {
        try {
            const separatedParameters = parameters.map((arr) => {
                return arr.split(":");
            });
            const columnData = separatedParameters.map((column) => {
                var _a;
                return (_a = columnBuilder_1.modelColumnBuilder(column[0], column[1])) !== null && _a !== void 0 ? _a : "";
            });
            const interfaceData = separatedParameters.map((column) => {
                var _a;
                return (_a = columnBuilder_1.modelInterfaceColumnBuilder(column[0], column[1])) !== null && _a !== void 0 ? _a : "";
            });
            models_template_1.createModelInterface(modelName, interfaceData);
            models_template_1.createModelFile(modelName, columnData);
            console.log(`The model file ${naming_handler_1.endOfStringFromManyToOne(modelName.toLowerCase())} has been created.`);
        }
        catch (err) {
            console.error(err);
        }
    }
    async generateSeed(tableName) {
        try {
            seed_template_1.createSeedFile(tableName);
            console.log(`The seed file ${naming_handler_1.endOfStringFromManyToOne(tableName.toLowerCase())} is created. Status: Pending`);
            await log_action_1.logAction(logs_messages_1.initializationMessages.successMessages.migrationGeneration +
                ` File: ${naming_handler_1.endOfStringFromManyToOne(tableName.toLowerCase())}`);
        }
        catch (err) {
            console.error(err);
            await log_action_1.logAction(logs_messages_1.initializationMessages.errorMessages.migrationGeneration +
                ` File: ${naming_handler_1.endOfStringFromManyToOne(tableName.toLowerCase())}` +
                " Message: " +
                err.message);
        }
    }
}
exports.generateExecutor = new GenerateExecutor();
//# sourceMappingURL=generate.executor.js.map