"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.createMigrationFile = void 0;
const fs_1 = __importDefault(require("fs"));
const path_constant_1 = require("../../../config/constants/path.constant");
const naming_handler_1 = require("../../Common/naming.handler");
const createMigrationFile = (tableName, parameters) => {
    const fileName = `${naming_handler_1.dateOfCreatingFile()}-create-${naming_handler_1.endOfStringFromManyToOne(tableName.toLowerCase())}.ts`;
    const migrationCode = 'import Sequelize, { QueryInterface } from "sequelize";\n' +
        "\n" +
        "export default {\n" +
        "  up: async (queryInterface: QueryInterface): Promise<void> => {\n" +
        `    await queryInterface.createTable("${tableName}", {\n` +
        "      id: {\n" +
        "        allowNull: false,\n" +
        "        autoIncrement: true,\n" +
        "        primaryKey: true,\n" +
        "        type: Sequelize.INTEGER,\n" +
        "      }," +
        `${parameters}` +
        "\n    });\n" +
        "  },\n" +
        "  down: async (queryInterface: QueryInterface): Promise<void> => {\n" +
        `    await queryInterface.dropTable("${tableName}");\n` +
        "  },\n" +
        "};\n";
    fs_1.default.writeFile(`${path_constant_1.pathConstant.userMigrationPath}/${fileName}`, migrationCode, async (err) => {
        if (err) {
            throw err;
        }
    });
};
exports.createMigrationFile = createMigrationFile;
//# sourceMappingURL=migrations.template.js.map