"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.createModelInterface = exports.createModelFile = void 0;
const naming_handler_1 = require("../../Common/naming.handler");
const fs_1 = __importDefault(require("fs"));
const path_constant_1 = require("../../../config/constants/path.constant");
const createModelFile = (tableName, parameters) => {
    const fileName = `${naming_handler_1.endOfStringFromManyToOne(tableName.toLowerCase())}.ts`;
    const modelCode = 'import { DataTypes } from "sequelize";\n' +
        'import connection from ""; //Enter your sequelize connect to database\n' +
        `import { I${naming_handler_1.endOfStringFromManyToOne(tableName)}Model } from "./interfaces/${naming_handler_1.endOfStringFromManyToOne(tableName).toLowerCase()}.interface";\n` +
        "\n" +
        `export const ${naming_handler_1.endOfStringFromManyToOne(tableName)}Model = connection.define<I${naming_handler_1.endOfStringFromManyToOne(tableName)}Model>("${tableName}", {\n` +
        "  id: {\n" +
        `    type: DataTypes.INTEGER.UNSIGNED,\n` +
        "    autoIncrement: true,\n" +
        "    primaryKey: true,\n" +
        "  }," +
        `${parameters}` +
        "\n});";
    fs_1.default.writeFile(`${path_constant_1.pathConstant.userModelPath}/${fileName}`, modelCode, async (err) => {
        if (err) {
            throw err;
        }
    });
};
exports.createModelFile = createModelFile;
const createModelInterface = (tableName, parameters) => {
    const fileName = `${naming_handler_1.endOfStringFromManyToOne(tableName.toLowerCase())}.interface.ts`;
    const interfaceCode = 'import { Model } from "sequelize";\n' +
        "\n" +
        `export interface I${naming_handler_1.endOfStringFromManyToOne(tableName)}Model extends Model {\n` +
        "  id: number," +
        `${parameters}` +
        "\n}";
    fs_1.default.writeFile(`${path_constant_1.pathConstant.userModelPath}/interfaces/${fileName}`, interfaceCode, async (err) => {
        if (err) {
            throw err;
        }
    });
};
exports.createModelInterface = createModelInterface;
//# sourceMappingURL=models.template.js.map